@@ -14,7 +14,7 @@ use overload '<=>' => sub { $_[0]->compare($_[1]) },
 # TODO: as_bin or similar
 
 # ABSTRACT: Universally Unique Identifiers FFI style
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 
 my $ffi = FFI::Platypus->new( api => 1 );
@@ -47,17 +47,19 @@ $ffi->lib(sub {
   return @lib;
 });
 
-$ffi->attach( [uuid_generate_random => '_generate_random'] => ['opaque']           => 'void'   => '$'  );
-$ffi->attach( [uuid_generate_time   => '_generate_time']   => ['opaque']           => 'void'   => '$'  );
-$ffi->attach( [uuid_unparse         => '_unparse']         => ['opaque', 'opaque'] => 'void'   => '$$' );
-$ffi->attach( [uuid_parse           => '_parse']           => ['string', 'opaque'] => 'int'    => '$$' );
-$ffi->attach( [uuid_copy            => '_copy']            => ['opaque', 'opaque'] => 'void'   => '$$' );
-$ffi->attach( [uuid_clear           => '_clear']           => ['opaque']           => 'void'   => '$'  );
-$ffi->attach( [uuid_type            => '_type']            => ['opaque']           => 'int'    => '$'  );
-$ffi->attach( [uuid_variant         => '_variant']         => ['opaque']           => 'int'    => '$'  );
-$ffi->attach( [uuid_time            => '_time']            => ['opaque', 'opaque'] => 'time_t' => '$$' );
-$ffi->attach( [uuid_is_null         => '_is_null']         => ['opaque']           => 'int'    => '$'  );
-$ffi->attach( [uuid_compare         => '_compare']         => ['opaque', 'opaque'] => 'int'    => '$$' );
+$ffi->mangler(sub { "uuid$_[0]" });
+
+$ffi->attach( _generate_random => ['opaque']           => 'void'   );
+$ffi->attach( _generate_time   => ['opaque']           => 'void'   );
+$ffi->attach( _unparse         => ['opaque', 'opaque'] => 'void'   );
+$ffi->attach( _parse           => ['string', 'opaque'] => 'int'    );
+$ffi->attach( _copy            => ['opaque', 'opaque'] => 'void'   );
+$ffi->attach( _clear           => ['opaque']           => 'void'   );
+$ffi->attach( _type            => ['opaque']           => 'int'    );
+$ffi->attach( _variant         => ['opaque']           => 'int'    );
+$ffi->attach( _time            => ['opaque', 'opaque'] => 'time_t' );
+$ffi->attach( _is_null         => ['opaque']           => 'int'    );
+$ffi->attach( _compare         => ['opaque', 'opaque'] => 'int'    );
 
 
 sub new
@@ -172,7 +174,7 @@ UUID::FFI - Universally Unique Identifiers FFI style
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -273,7 +275,7 @@ Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Graham Ollis.
+This software is copyright (c) 2014-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
